pub struct Dr7Flags(/* private fields */);Expand description
Debug control flags of the Dr7 register.
Implementations
Sourceimpl Dr7Flags
impl Dr7Flags
Sourcepub const LOCAL_BREAKPOINT_0_ENABLE: Self
pub const LOCAL_BREAKPOINT_0_ENABLE: Self
Breakpoint 0 is enabled for the current task.
Sourcepub const LOCAL_BREAKPOINT_1_ENABLE: Self
pub const LOCAL_BREAKPOINT_1_ENABLE: Self
Breakpoint 1 is enabled for the current task.
Sourcepub const LOCAL_BREAKPOINT_2_ENABLE: Self
pub const LOCAL_BREAKPOINT_2_ENABLE: Self
Breakpoint 2 is enabled for the current task.
Sourcepub const LOCAL_BREAKPOINT_3_ENABLE: Self
pub const LOCAL_BREAKPOINT_3_ENABLE: Self
Breakpoint 3 is enabled for the current task.
Sourcepub const GLOBAL_BREAKPOINT_0_ENABLE: Self
pub const GLOBAL_BREAKPOINT_0_ENABLE: Self
Breakpoint 0 is enabled for all tasks.
Sourcepub const GLOBAL_BREAKPOINT_1_ENABLE: Self
pub const GLOBAL_BREAKPOINT_1_ENABLE: Self
Breakpoint 1 is enabled for all tasks.
Sourcepub const GLOBAL_BREAKPOINT_2_ENABLE: Self
pub const GLOBAL_BREAKPOINT_2_ENABLE: Self
Breakpoint 2 is enabled for all tasks.
Sourcepub const GLOBAL_BREAKPOINT_3_ENABLE: Self
pub const GLOBAL_BREAKPOINT_3_ENABLE: Self
Breakpoint 3 is enabled for all tasks.
Sourcepub const LOCAL_EXACT_BREAKPOINT_ENABLE: Self
pub const LOCAL_EXACT_BREAKPOINT_ENABLE: Self
Enable detection of exact instruction causing a data breakpoint condition for the current task.
This is not supported by x86_64 processors, but is recommended to be enabled for backward and forward compatibility.
Sourcepub const GLOBAL_EXACT_BREAKPOINT_ENABLE: Self
pub const GLOBAL_EXACT_BREAKPOINT_ENABLE: Self
Enable detection of exact instruction causing a data breakpoint condition for all tasks.
This is not supported by x86_64 processors, but is recommended to be enabled for backward and forward compatibility.
Sourcepub const RESTRICTED_TRANSACTIONAL_MEMORY: Self
pub const RESTRICTED_TRANSACTIONAL_MEMORY: Self
Enables advanced debugging of RTM transactional regions.
The RTM flag in the IA32_DEBUGCTL [Msr] must also be set.
Sourcepub const GENERAL_DETECT_ENABLE: Self
pub const GENERAL_DETECT_ENABLE: Self
Enables debug register protection.
This will cause a debug exception before any access to a debug register.
Sourceimpl Dr7Flags
impl Dr7Flags
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Dr7Flags
impl Dr7Flags
Sourcepub const fn iter(&self) -> Iter<Dr7Flags>
pub const fn iter(&self) -> Iter<Dr7Flags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Dr7Flags>
pub const fn iter_names(&self) -> IterNames<Dr7Flags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Dr7Flags
impl Dr7Flags
Sourcepub fn local_breakpoint_enable(n: DebugAddressRegisterNumber) -> Self
pub fn local_breakpoint_enable(n: DebugAddressRegisterNumber) -> Self
Returns the local breakpoint enable flag of the provided debug address register.
Sourcepub fn global_breakpoint_enable(n: DebugAddressRegisterNumber) -> Self
pub fn global_breakpoint_enable(n: DebugAddressRegisterNumber) -> Self
Returns the global breakpoint enable flag of the provided debug address register.